==> vpn-user-portal-3.5.6.tgz: vpn-user-portal/locale/nl-NL.php <==
<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    '#Active (Max #Available) Connections' => '#Actieve (Max #beschikbare) verbindingen',
    '#Connections in 5 minute intervals' => '#Verbindingen per 5 minuten',
    '#Unique Guest Users' => '#Unieke gastgebruikers',
    '#Unique Users' => '#Unieke gebruikers',
    '#Unique users and max #connections per day' => '#Unieke gebruikers en maximaal #verbindingen per dag',
    'ACL Permission List' => 'ACL-lijst',
    'Account' => 'Account',
    'Active' => 'Actief',
    'Active Configurations' => 'Actieve configuraties',
    'Aggregated' => 'Geaggregeerd',
    'All' => 'Alle',
    'An application attempts to establish a VPN connection.' => 'Een applicatie probeert een VPN-verbinding op te zetten.',
    'An error occurred.' => 'Er is een fout opgetreden.',
    'Application Usage' => 'Applicatiegebruik',
    'Approve' => 'Toestaan',
    'Approve Application' => 'Applicatie toestaan',
    'Authentication Data' => 'Authenticatiegegevens',
    'Authorized Applications' => 'Geautoriseerde applicaties',
    'Authorized On' => 'Toegestaan',
    'Available Profiles' => 'Beschikbare profielen',
    'Block LAN' => 'Blokkeer LAN',
    'CA' => 'CA',
    'CPU Usage:' => 'CPU-gebruik:',
    'Change Password' => 'Wijzig wachtwoord',
    'Configurations' => 'Configuraties',
    'Confirm' => 'Bevestig',
    'Connected' => 'Verbonden',
    'Connections' => 'Verbindingen',
    'Created On' => 'Aangemaakt',
    'Current Password' => 'Huidig wachtwoord',
    'Current Password not correct!' => 'Huidig wachtwoord niet correct!',
    'Currently there are no clients connected to this profile.' => 'Op dit moment zijn er geen verbindingen met dit profiel.',
    'DNS Search Domain(s)' => 'DNS-zoekdomein(en)',
    'DNS Server(s)' => 'DNS-server(s)',
    'Danger Zone' => 'Gevarenzone',
    'Date/Time' => 'Datum/Tijd',
    'Default Gateway' => 'Default Gateway',
    'Delete' => 'Verwijderen',
    'Delete Account' => 'Account verwijderen',
    'Delete Account Data' => 'Accountgegevens verwijderen',
    'Disable Account' => 'Account deactiveren',
    'Disabled' => 'Uitgeschakeld',
    'Disconnected' => 'Verbroken',
    'Distribution of unique users over the VPN applications.' => 'Verdeling van unieke gebruikers over de VPN-applicaties.',
    'Download' => 'Download',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Het downloaden van VPN-configuraties is niet toegestaan. Gebruik een VPN applicatie.',
    'Enable Account' => 'Account activeren',
    'Error' => 'Fout',
    'Excluded Route(s)' => 'Uitgesloten route(s)',
    'Expires On' => 'Verloopt',
    'Export (CSV)' => 'Exporteren (CSV)',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Zoek het gebruikerskenmerk van een gebruiker die een specifieke IPv4- of IPv6-adres gebruikte.',
    'Fingerprint' => 'Fingerprint',
    'Here you can change the password for your account.' => 'Hier kun je het wachtwoord van je account wijzigen.',
    'Home' => 'Home',
    'Hostname' => 'Hostname',
    'IP Address' => 'IP-adres',
    'IPs' => 'IP’s',
    'IPv4 Prefix' => 'IPv4-prefix',
    'IPv6 Prefix' => 'IPv6-prefix',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importeer of kopieer/plak deze configuratie in je WireGuard applicatie.',
    'Info' => 'Info',
    'Issues' => 'Problemen',
    'Live' => 'Live',
    'Log' => 'Log',
    'MTU' => 'MTU',
    'Max #Connections' => 'Max #verbindingen',
    'More' => 'Meer',
    'N/A' => 'N.v.t.',
    'Name' => 'Naam',
    'New Configuration' => 'Nieuwe configuratie',
    'New Password' => 'Nieuw wachtwoord',
    'New Password (confirm)' => 'Nieuw wachtwoord (bevestigen)',
    'New Password and New Password (confirm) MUST match!' => 'Nieuw wachtwoord en nieuw wachtwoord (bevestigen) moeten gelijk zijn!',
    'No Permission(s)' => 'Geen permissie(s)',
    'No VPN profiles are available for your account.' => 'Er zijn geen VPN-profielen beschikbaar voor jouw account.',
    'Node URL' => 'Node URL',
    'Node(s)' => 'Node(s)',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Haal een nieuw VPN-configuratiebestand op voor gebruik in je VPN-client.',
    'Offered Ports' => 'Aangeboden poorten',
    'Offline' => 'Offline',
    'Online' => 'Online',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Sta dit alleen toe als je probeert een VPN-verbinding op te zetten met deze applicatie!',
    'OpenVPN' => 'OpenVPN',
    'OpenVPN (Prefer TCP)' => 'OpenVPN (Voorkeur voor TCP)',
    'OpenVPN (Prefer UDP)' => 'OpenVPN (Voorkeur voor UDP)',
    'OpenVPN Server Log' => 'OpenVPN server log',
    'Password' => 'Wachtwoord',
    'Permissions' => 'Permissies',
    'Please sign in with your username and password.' => 'Log in met je gebruikersnaam en wachtwoord.',
    'Port' => 'Poort',
    'Ports' => 'Poorten',
    'Preferred Protocol' => 'Voorkeursprotocol',
    'Profile' => 'Profiel',
    'Profile ID' => 'Profiel-ID',
    'Profile Usage' => 'Profielgebruik',
    'Profile(s)' => 'Profiel(en)',
    'Public Key' => 'Public Key',
    'Refresh' => 'Verversen',
    'Results' => 'Resultaten',
    'Revoke' => 'Intrekken',
    'Route(s)' => 'Route(s)',
    'Search' => 'Zoeken',
    'Select a profile and choose a name, e.g. "Phone".' => 'Selecteer een profiel en kies een naam, bijvoorbeeld "Telefoon"',
    'Server' => 'Server',
    'Sign In' => 'Inloggen',
    'Sign Out' => 'Uitloggen',
    'Stats' => 'Statistieken',
    'The <em>Date/Time</em> MUST be in UTC.' => 'De opgegeven <em>Datum/tijd</em> moet in UTC zijn.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'Het <em>Datum/tijd</em> veld accepteert datums in het formaat <code>Y-m-d H:i:s</code>, bijvoorbeeld <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'De inloggegevens zijn niet correct.',
    'The list of applications you authorized to create a VPN connection.' => 'De lijst van applicaties die je toestemming hebt gegeven een VPN-verbinding op te zetten.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Het maximaal aantal gelijktijdig verbonden VPN-clients op een bepaald moment in de afgelopen week',
    'The most recent VPN connections with this account.' => 'De meest recente VPN-verbindingen van dit account.',
    'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => 'Het op dit moment aantal VPN-verbindingen, en het maximaal aantal VPN-verbindingen gebaseerd op de beschikbare IP-space van dit profiel.',
    'The number of unique guest users connecting to the VPN service in the last week' => 'Het aantal unieke gastgebruikers verbonden met de VPN-dienst in de afgelopen week',
    'The number of unique users connecting to the VPN service in the last week' => 'Het aantal unieke gebruikers verbonden met de VPN-dienst in de afgelopen week',
    'The table below shows the per profile VPN usage over the last week.' => 'De tabel hieronder laat het VPN-gebruik zien over de laatste week.',
    'There are no results matching your criteria.' => 'Er zijn geen resultaten die voldoen aan de criteria.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Deze server gebruikt een externe gebruikersdatabase. Een account verwijderen voorkomt niet dat de gebruiker (opnieuw) kan inloggen!',
    'This user does not have any active configurations.' => 'Deze gebruiker heeft geen actieve configuraties.',
    'This user does not have any connections.' => 'Deze gebruiker heeft geen verbindingen.',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Om te voorkomen dat kwaadaardige applicaties namens jou in het geheim een VPN-verbinding op kunnen zetten moet je dit eerst expliciet toestaan.',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Gebruik de WireGuard-applicatie op je mobiele device om deze QR-code te scannen.',
    'User ID' => 'Gebruikers-ID',
    'Username' => 'Gebruikersnaam',
    'Users' => 'Gebruikers',
    'VPN Portal' => 'VPN Portal',
    'Version' => 'Versie',
    'Welcome to this VPN service!' => 'Welkom bij deze VPN-dienst!',
    'Why is this necessary?' => 'Waarom is dit nodig?',
    'WireGuard' => 'WireGuard',
    'WireGuard Configuration' => 'WireGuard-configuratie',
    'You can download the detailed VPN usage statistics below.' => 'Je kunt de gedetailleerde VPN-statistieken hieronder downloaden.',
    'You cannot manage your own user account.' => 'Je kunt niet je eigen account beheren.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Het maximale aantal actieve VPN-configuraties is bereikt. Verwijder er eerst eentje.',
    'Your account does not have access to any VPN profile.' => 'Je account heeft geen toegang tot een VPN-profiel.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Je nieuwe configuratie zal verlopen op %expiryDate%. Kom hier terug om een nieuwe configuratie op te halen nadat deze verloopt!',
];

==> vpn-user-portal-3.9.4.tgz: vpn-user-portal/locale/nl-NL.php <==
<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    '#Active (Max #Available) Connections' => '#Actieve (Max #beschikbare) verbindingen',
    '#Connections in 5 minute intervals' => '#Verbindingen per 5 minuten',
    '#Unique Guest Users' => '#Unieke gastgebruikers',
    '#Unique Users' => '#Unieke gebruikers',
    '#Unique users and max #connections per day' => '#Unieke gebruikers en maximaal #verbindingen per dag',
    'ACL Permission List' => 'ACL-lijst',
    'Account' => 'Account',
    'Active' => 'Actief',
    'Active Configurations' => 'Actieve configuraties',
    'Additional Credential' => 'Extra inloggegeven',
    'Aggregated' => 'Geaggregeerd',
    'All' => 'Alle',
    'An application attempts to establish a VPN connection.' => 'Een applicatie probeert een VPN-verbinding op te zetten.',
    'An error occurred.' => 'Er is een fout opgetreden.',
    'Application Usage' => 'Applicatiegebruik',
    'Approve' => 'Toestaan',
    'Approve Application' => 'Applicatie toestaan',
    'Authentication Data' => 'Authenticatiegegevens',
    'Authorized Applications' => 'Geautoriseerde applicaties',
    'Authorized On' => 'Toegestaan',
    'Available Profiles' => 'Beschikbare profielen',
    'Block LAN' => 'Blokkeer LAN',
    'CA' => 'CA',
    'CPU Usage:' => 'CPU-gebruik:',
    'Change Password' => 'Wijzig wachtwoord',
    'Configurations' => 'Configuraties',
    'Confirm' => 'Bevestig',
    'Connected' => 'Verbonden',
    'Connections' => 'Verbindingen',
    'Created On' => 'Aangemaakt',
    'Current Password' => 'Huidig wachtwoord',
    'Current Password not correct!' => 'Huidig wachtwoord niet correct!',
    'Currently there are no clients connected to this profile.' => 'Op dit moment zijn er geen verbindingen met dit profiel.',
    'DNS Search Domain(s)' => 'DNS-zoekdomein(en)',
    'DNS Server(s)' => 'DNS-server(s)',
    'Danger Zone' => 'Gevarenzone',
    'Database' => 'Database',
    'Date/Time' => 'Datum/Tijd',
    'Default Gateway' => 'Default Gateway',
    'Delete' => 'Verwijderen',
    'Delete Account' => 'Account verwijderen',
    'Delete Account Data' => 'Accountgegevens verwijderen',
    'Disable Account' => 'Account deactiveren',
    'Disabled' => 'Uitgeschakeld',
    'Disconnected' => 'Verbroken',
    'Distribution of unique users over the VPN applications.' => 'Verdeling van unieke gebruikers over de VPN-applicaties.',
    'Download' => 'Download',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Het downloaden van VPN-configuraties is niet toegestaan. Gebruik een VPN applicatie.',
    'Driver' => 'Stuurprogramma',
    'Enable Account' => 'Account activeren',
    'Error' => 'Fout',
    'Excluded Route(s)' => 'Uitgesloten route(s)',
    'Expires On' => 'Verloopt',
    'Export (CSV)' => 'Exporteren (CSV)',
    'Extend' => 'Verlengen',
    'Extend the validity of the configuration until %expiryDate%' => 'Verleng de geldigheid van de configuratie tot %expiryDate%',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Zoek het gebruikerskenmerk van een gebruiker die een specifieke IPv4- of IPv6-adres gebruikte.',
    'Fingerprint' => 'Fingerprint',
    'Here you can change the password for your account.' => 'Hier kun je het wachtwoord van je account wijzigen.',
    'Home' => 'Home',
    'Hostname' => 'Hostname',
    'IP Address' => 'IP-adres',
    'IPs' => 'IP’s',
    'IPv4 Prefix' => 'IPv4-prefix',
    'IPv6 Prefix' => 'IPv6-prefix',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importeer of kopieer/plak deze configuratie in je WireGuard applicatie.',
    'Info' => 'Info',
    'Issues' => 'Problemen',
    'Keepalive' => 'Keepalive',
    'Last Used' => 'Laatst gebruikt',
    'Live' => 'Live',
    'Log' => 'Log',
    'MTU' => 'MTU',
    'Maintenance' => 'Onderhoud',
    'Max #Connections' => 'Max #verbindingen',
    'More' => 'Meer',
    'N/A' => 'N.v.t.',
    'Name' => 'Naam',
    'New Configuration' => 'Nieuwe configuratie',
    'New Password' => 'Nieuw wachtwoord',
    'New Password (confirm)' => 'Nieuw wachtwoord (bevestigen)',
    'New Password and New Password (confirm) MUST match!' => 'Nieuw wachtwoord en nieuw wachtwoord (bevestigen) moeten gelijk zijn!',
    'No Permission(s)' => 'Geen permissie(s)',
    'No VPN profiles are available for your account.' => 'Er zijn geen VPN-profielen beschikbaar voor jouw account.',
    'Node URL' => 'Node URL',
    'Node(s)' => 'Node(s)',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Haal een nieuw VPN-configuratiebestand op voor gebruik in je VPN-client.',
    'Offered Ports' => 'Aangeboden poorten',
    'Offline' => 'Offline',
    'Online' => 'Online',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Sta dit alleen toe als je probeert een VPN-verbinding op te zetten met deze applicatie!',
    'OpenVPN' => 'OpenVPN',
    'OpenVPN (Prefer TCP)' => 'OpenVPN (Voorkeur voor TCP)',
    'OpenVPN (Prefer UDP)' => 'OpenVPN (Voorkeur voor UDP)',
    'OpenVPN Server Log' => 'OpenVPN server log',
    'Password' => 'Wachtwoord',
    'Permissions' => 'Permissies',
    'Please sign in with your username and password.' => 'Log in met je gebruikersnaam en wachtwoord.',
    'Port' => 'Poort',
    'Ports' => 'Poorten',
    'Preferred Protocol' => 'Voorkeursprotocol',
    'Profile' => 'Profiel',
    'Profile ID' => 'Profiel-ID',
    'Profile Usage' => 'Profielgebruik',
    'Profile no longer available with your current permissions.' => 'Profiel is niet meer beschikbaar met je huidige permissies.',
    'Profile(s)' => 'Profiel(en)',
    'Proxy URL' => 'Proxy URL',
    'Public Key' => 'Public Key',
    'Refresh' => 'Verversen',
    'Results' => 'Resultaten',
    'Revoke' => 'Intrekken',
    'Route(s)' => 'Route(s)',
    'Search' => 'Zoeken',
    'Select a profile and choose a name, e.g. "Phone".' => 'Selecteer een profiel en kies een naam, bijvoorbeeld "Telefoon"',
    'Server' => 'Server',
    'Sign In' => 'Inloggen',
    'Sign Out' => 'Uitloggen',
    'Sorted by "Last Used", most recently used first.' => 'Gesorteerd op "Laatst gebruikt", meest recent eerst.',
    'Stats' => 'Statistieken',
    'TCP' => 'TCP',
    'The <em>Date/Time</em> MUST be in UTC.' => 'De opgegeven <em>Datum/tijd</em> moet in UTC zijn.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'Het <em>Datum/tijd</em> veld accepteert datums in het formaat <code>Y-m-d H:i:s</code>, bijvoorbeeld <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'De inloggegevens zijn niet correct.',
    'The list of applications you authorized to create a VPN connection.' => 'De lijst van applicaties die je toestemming hebt gegeven een VPN-verbinding op te zetten.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Het maximaal aantal gelijktijdig verbonden VPN-clients op een bepaald moment in de afgelopen week',
    'The most recent VPN connections with this account.' => 'De meest recente VPN-verbindingen van dit account.',
    'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => 'Het op dit moment aantal VPN-verbindingen, en het maximaal aantal VPN-verbindingen gebaseerd op de beschikbare IP-space van dit profiel.',
    'The number of unique guest users connecting to the VPN service in the last week' => 'Het aantal unieke gastgebruikers verbonden met de VPN-dienst in de afgelopen week',
    'The number of unique users connecting to the VPN service in the last week' => 'Het aantal unieke gebruikers verbonden met de VPN-dienst in de afgelopen week',
    'The table below shows the per profile VPN usage over the last week.' => 'De tabel hieronder laat het VPN-gebruik zien over de laatste week.',
    'There are no results matching your criteria.' => 'Er zijn geen resultaten die voldoen aan de criteria.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Deze server gebruikt een externe gebruikersdatabase. Een account verwijderen voorkomt niet dat de gebruiker (opnieuw) kan inloggen!',
    'This user does not have any active configurations.' => 'Deze gebruiker heeft geen actieve configuraties.',
    'This user does not have any authorized applications.' => 'Deze gebruiker heeft geen applicaties toegestaan.',
    'This user does not have any connections.' => 'Deze gebruiker heeft geen verbindingen.',
    'To complete the sign in, you need to provide an additional credential.' => 'Om het inloggen af te ronden is er nog een inloggegeven nodig.',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Om te voorkomen dat kwaadaardige applicaties namens jou in het geheim een VPN-verbinding op kunnen zetten moet je dit eerst expliciet toestaan.',
    'Transport Protocol(s)' => 'Transportprotocollen',
    'UDP' => 'UDP',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Gebruik de WireGuard-applicatie op je mobiele device om deze QR-code te scannen.',
    'User ID' => 'Gebruikers-ID',
    'Username' => 'Gebruikersnaam',
    'Users' => 'Gebruikers',
    'VPN Portal' => 'VPN Portal',
    'Version' => 'Versie',
    'Welcome to this VPN service!' => 'Welkom bij deze VPN-dienst!',
    'Why is this necessary?' => 'Waarom is dit nodig?',
    'WireGuard' => 'WireGuard',
    'WireGuard (TCP)' => 'WireGuard (TCP)',
    'WireGuard (UDP)' => 'WireGuard (UDP)',
    'WireGuard Configuration' => 'WireGuard-configuratie',
    'You can download the detailed VPN usage statistics below.' => 'Je kunt de gedetailleerde VPN-statistieken hieronder downloaden.',
    'You cannot manage your own user account.' => 'Je kunt niet je eigen account beheren.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Het maximale aantal actieve VPN-configuraties is bereikt. Verwijder er eerst eentje.',
    'Your account does not have access to any VPN profile.' => 'Je account heeft geen toegang tot een VPN-profiel.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Je nieuwe configuratie zal verlopen op %expiryDate%. Kom hier terug om een nieuwe configuratie op te halen nadat deze verloopt!',
];
